@@ -33,10 +33,12 @@ from sertit import files, rasters
 from sertit.misc import ListEnum
 
 from eoreader import cache, utils
-from eoreader.bands import BandNames, SpectralBandMap
-from eoreader.bands import SpectralBandNames as spb
 from eoreader.bands import (
-    indices,
+    GREEN,
+    NEEDED_BANDS,
+    BandNames,
+    SpectralBandMap,
+    compute_index,
     is_clouds,
     is_dem,
     is_index,
@@ -154,7 +156,7 @@ class OpticalProduct(Product):
         Returns:
             str: Default band
         """
-        return spb.GREEN
+        return GREEN
 
     def get_default_band_path(self, **kwargs) -> Union[CloudPath, Path]:
         """
@@ -326,11 +328,6 @@ class OpticalProduct(Product):
             )
             # If raw data, clean it !
             if AnyPath(band_path).name != clean_band_path.name:
-                # Manage reflectance
-                if kwargs.get(TO_REFLECTANCE, True):
-                    LOGGER.debug(f"Converting {band.name} to reflectance")
-                    band_arr = self._to_reflectance(band_arr, band_path, band)
-
                 # Clean pixels
                 cleaning_method = CleanMethod.from_value(
                     kwargs.get(CLEAN_OPTICAL, DEF_CLEAN_METHOD)
@@ -347,6 +344,12 @@ class OpticalProduct(Product):
                     )
                 band_arr.attrs["cleaning_method"] = cleaning_method.value
 
+                # Manage reflectance
+                # (after cleaning -> don't alter pixel value before managing nodata)
+                if kwargs.get(TO_REFLECTANCE, True):
+                    LOGGER.debug(f"Converting {band.name} to reflectance")
+                    band_arr = self._to_reflectance(band_arr, band_path, band)
+
                 # Write on disk
                 try:
                     utils.write(
@@ -441,7 +444,7 @@ class OpticalProduct(Product):
             mask = np.expand_dims(mask, axis=0)
 
         # Set masked values to nodata
-        return band_arr.where(mask == 0)
+        return band_arr.copy(data=np.where(mask == 0, band_arr, np.nan))
 
     def _load(
         self,
@@ -499,23 +502,25 @@ class OpticalProduct(Product):
         # Get all bands to be open
         bands_to_load = band_list.copy()
         for idx in index_list:
-            bands_to_load += indices.NEEDED_BANDS[idx]
+            bands_to_load += NEEDED_BANDS[idx]
 
         # Load band arrays (only keep unique bands: open them only one time !)
         unique_bands = list(set(bands_to_load))
         if unique_bands:
             LOGGER.debug(f"Loading bands {to_str(unique_bands)}")
-        bands = self._load_bands(
+        loaded_bands = self._load_bands(
             unique_bands, resolution=resolution, size=size, **kwargs
         )
 
         # Compute index (they conserve the nodata)
         if index_list:
             LOGGER.debug(f"Loading indices {to_str(index_list)}")
-        bands_dict = {idx: idx(bands) for idx in index_list}
+        bands_dict = {
+            idx: compute_index(index=idx, bands=loaded_bands) for idx in index_list
+        }
 
         # Add bands
-        bands_dict.update({band: bands[band] for band in band_list})
+        bands_dict.update({band: loaded_bands[band] for band in band_list})
 
         # Add DEM
         if dem_list:
@@ -875,11 +880,11 @@ class OpticalProduct(Product):
         Returns:
             list: Representation list (constellation specific)
         """
-        repr = []
+        repr_str = []
         if self._has_cloud_cover:
-            repr.append(f"\tcloud cover: {self.get_cloud_cover()}")
+            repr_str.append(f"\tcloud cover: {self.get_cloud_cover()}")
 
         if self.tile_name is not None:
-            repr.append(f"\ttile name: {self.tile_name}")
+            repr_str.append(f"\ttile name: {self.tile_name}")
 
-        return repr
+        return repr_str
