@@ -20,62 +20,67 @@ See `here <http://www.engesat.com.br/wp-content/uploads/S5-ST-73-1-CN_2_9-Spec-F
 for more information.
 """
 import logging
-import time
-from datetime import date, datetime, timedelta
+from datetime import timedelta
 from enum import unique
 from pathlib import Path
 from typing import Union
 
-import geopandas as gpd
 import numpy as np
 import xarray as xr
 from cloudpathlib import CloudPath
 from lxml import etree
 from rasterio import crs as riocrs
-from sertit import files, rasters, vectors
+from sertit import files
 from sertit.misc import ListEnum
-from shapely.geometry import Polygon, box
 
 from eoreader import cache
-from eoreader.bands import BandNames, SpectralBand
-from eoreader.bands import spectral_bands as spb
+from eoreader.bands import (
+    GREEN,
+    NARROW_NIR,
+    NIR,
+    PAN,
+    RED,
+    SWIR_1,
+    BandNames,
+    SpectralBand,
+)
 from eoreader.exceptions import InvalidProductError
-from eoreader.products import VhrProduct
+from eoreader.products import DimapV1Product
 from eoreader.products.optical.optical_product import RawUnits
 from eoreader.reader import Constellation
 from eoreader.stac import GSD, ID, NAME, WV_MAX, WV_MIN
-from eoreader.utils import DATETIME_FMT, EOREADER_NAME, simplify
+from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
 _DIMAP_BAND_MTD = {
-    spb.PAN: "PAN",
-    spb.GREEN: "XS1",
-    spb.RED: "XS2",
-    spb.NIR: "XS3",
-    spb.NARROW_NIR: "XS3",
-    spb.SWIR_1: "XS4",
+    PAN: "PAN",
+    GREEN: "XS1",
+    RED: "XS2",
+    NIR: "XS3",
+    NARROW_NIR: "XS3",
+    SWIR_1: "XS4",
 }
 
 # https://spot.cnes.fr/sites/default/files/migration/smsc/spot/calibration_synthesis_SPOT1245_ed1.pdf (3.3)
 # HRVIR 1, 2
 _SPOT4_E0 = {
-    spb.PAN: [1570.2, 1589],
-    spb.GREEN: [1842.9, 1850.9],
-    spb.RED: [1570.2, 1589],
-    spb.NIR: [1052.1, 1054.8],
-    spb.NARROW_NIR: [1052.1, 1054.8],
-    spb.SWIR_1: [235.84, 241.93],
+    PAN: [1570.2, 1589],
+    GREEN: [1842.9, 1850.9],
+    RED: [1570.2, 1589],
+    NIR: [1052.1, 1054.8],
+    NARROW_NIR: [1052.1, 1054.8],
+    SWIR_1: [235.84, 241.93],
 }
 
 # HRG 1, 2
 _SPOT5_E0 = {
-    spb.PAN: [1764.2, 1775],
-    spb.GREEN: [1859.8, 1859.8],
-    spb.RED: [1575.3, 1577.6],
-    spb.NIR: [1043.9, 1048.2],
-    spb.NARROW_NIR: [1043.9, 1048.2],
-    spb.SWIR_1: [238.87, 237.78],
+    PAN: [1764.2, 1775],
+    GREEN: [1859.8, 1859.8],
+    RED: [1575.3, 1577.6],
+    NIR: [1043.9, 1048.2],
+    NARROW_NIR: [1043.9, 1048.2],
+    SWIR_1: [238.87, 237.78],
 }
 """
 The values of the normalized solar irradiance have been computed using WMO (World Meteorogical Organization) spectral solar irradiance.
@@ -181,7 +186,7 @@ class Spot45ProductType(ListEnum):
     """
 
 
-class Spot45Product(VhrProduct):
+class Spot45Product(DimapV1Product):
     """
     Class of SPOT4/5 products.
     See `here <http://www.engesat.com.br/wp-content/uploads/S5-ST-73-1-CN_2_9-Spec-Format-Produits-SPOT.pdf>`_
@@ -307,27 +312,27 @@ class Spot45Product(VhrProduct):
         if self.constellation == Constellation.SPOT4:
             # Create spectral bands
             pan = SpectralBand(
-                eoreader_name=spb.PAN,
+                eoreader_name=PAN,
                 **{NAME: "PAN", ID: 1, GSD: self._pan_res, WV_MIN: 610, WV_MAX: 680},
             )
 
             green = SpectralBand(
-                eoreader_name=spb.GREEN,
+                eoreader_name=GREEN,
                 **{NAME: "GREEN", ID: 3, GSD: self._ms_res, WV_MIN: 500, WV_MAX: 590},
             )
 
             red = SpectralBand(
-                eoreader_name=spb.RED,
+                eoreader_name=RED,
                 **{NAME: "RED", ID: 2, GSD: self._ms_res, WV_MIN: 610, WV_MAX: 680},
             )
 
             nir = SpectralBand(
-                eoreader_name=spb.NIR,
+                eoreader_name=NIR,
                 **{NAME: "NIR", ID: 1, GSD: self._ms_res, WV_MIN: 790, WV_MAX: 890},
             )
 
             swir1 = SpectralBand(
-                eoreader_name=spb.SWIR_1,
+                eoreader_name=SWIR_1,
                 **{
                     NAME: "SWIR_1",
                     ID: 4,
@@ -339,43 +344,43 @@ class Spot45Product(VhrProduct):
         else:
             # Create spectral bands
             pan = SpectralBand(
-                eoreader_name=spb.PAN,
+                eoreader_name=PAN,
                 **{NAME: "PAN", ID: 1, GSD: self._pan_res, WV_MIN: 490, WV_MAX: 690},
             )
 
             green = SpectralBand(
-                eoreader_name=spb.GREEN,
+                eoreader_name=GREEN,
                 **{NAME: "GREEN", ID: 3, GSD: self._ms_res, WV_MIN: 490, WV_MAX: 610},
             )
 
             red = SpectralBand(
-                eoreader_name=spb.RED,
+                eoreader_name=RED,
                 **{NAME: "RED", ID: 2, GSD: self._ms_res, WV_MIN: 610, WV_MAX: 680},
             )
 
             nir = SpectralBand(
-                eoreader_name=spb.NIR,
+                eoreader_name=NIR,
                 **{NAME: "NIR", ID: 1, GSD: self._ms_res, WV_MIN: 780, WV_MAX: 890},
             )
 
             swir1 = SpectralBand(
-                eoreader_name=spb.SWIR_1,
+                eoreader_name=SWIR_1,
                 **{NAME: "SWIR_1", ID: 4, GSD: 20.0, WV_MIN: 1580, WV_MAX: 1750},
             )
 
         # Manage bands of the product
         if self.band_combi in [Spot4BandCombination.M, Spot5BandCombination.HM]:
-            self.bands.map_bands({spb.PAN: pan})
+            self.bands.map_bands({PAN: pan})
         elif self.band_combi in [
             Spot4BandCombination.X,
             Spot5BandCombination.X,
         ]:
             self.bands.map_bands(
                 {
-                    spb.GREEN: green,
-                    spb.RED: red,
-                    spb.NIR: nir,
-                    spb.NARROW_NIR: nir,
+                    GREEN: green,
+                    RED: red,
+                    NIR: nir,
+                    NARROW_NIR: nir,
                 }
             )
         elif self.band_combi in [
@@ -384,21 +389,21 @@ class Spot45Product(VhrProduct):
         ]:
             self.bands.map_bands(
                 {
-                    spb.GREEN: green.update(gsd=self._pan_res),
-                    spb.RED: red.update(gsd=self._pan_res),
-                    spb.NIR: nir.update(gsd=self._pan_res),
-                    spb.NARROW_NIR: nir.update(gsd=self._pan_res),
+                    GREEN: green.update(gsd=self._pan_res),
+                    RED: red.update(gsd=self._pan_res),
+                    NIR: nir.update(gsd=self._pan_res),
+                    NARROW_NIR: nir.update(gsd=self._pan_res),
                 }
             )
         elif self.band_combi == Spot5BandCombination.T:
-            self.bands.map_bands({spb.PAN: pan.update(gsd=self._supermode_res)})
+            self.bands.map_bands({PAN: pan.update(gsd=self._supermode_res)})
         elif self.band_combi == Spot5BandCombination.TX:
             self.bands.map_bands(
                 {
-                    spb.GREEN: green.update(gsd=self._supermode_res),
-                    spb.RED: red.update(gsd=self._supermode_res),
-                    spb.NIR: nir.update(gsd=self._supermode_res),
-                    spb.NARROW_NIR: nir.update(gsd=self._supermode_res),
+                    GREEN: green.update(gsd=self._supermode_res),
+                    RED: red.update(gsd=self._supermode_res),
+                    NIR: nir.update(gsd=self._supermode_res),
+                    NARROW_NIR: nir.update(gsd=self._supermode_res),
                 }
             )
         elif self.band_combi in [
@@ -407,21 +412,21 @@ class Spot45Product(VhrProduct):
         ]:
             self.bands.map_bands(
                 {
-                    spb.GREEN: green,
-                    spb.RED: red,
-                    spb.NIR: nir,
-                    spb.NARROW_NIR: nir,
-                    spb.SWIR_1: swir1,
+                    GREEN: green,
+                    RED: red,
+                    NIR: nir,
+                    NARROW_NIR: nir,
+                    SWIR_1: swir1,
                 }
             )
         elif self.band_combi == Spot4BandCombination.MI:
             self.bands.map_bands(
                 {
-                    spb.GREEN: green.update(gsd=self._pan_res),
-                    spb.RED: red.update(gsd=self._pan_res),
-                    spb.NIR: nir.update(gsd=self._pan_res),
-                    spb.NARROW_NIR: nir.update(gsd=self._pan_res),
-                    spb.SWIR_1: swir1.update(gsd=self._pan_res),
+                    GREEN: green.update(gsd=self._pan_res),
+                    RED: red.update(gsd=self._pan_res),
+                    NIR: nir.update(gsd=self._pan_res),
+                    NARROW_NIR: nir.update(gsd=self._pan_res),
+                    SWIR_1: swir1.update(gsd=self._pan_res),
                 }
             )
         else:
@@ -429,44 +434,6 @@ class Spot45Product(VhrProduct):
                 f"Unusual band combination: {self.band_combi.name}"
             )
 
-    @cache
-    def crs(self) -> riocrs.CRS:
-        """
-        Get UTM projection of the tile
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> path = r"IMG_PHR1B_PMS_001"
-            >>> prod = Reader().open(path)
-            >>> prod.crs()
-            CRS.from_epsg(32618)
-
-        Returns:
-            rasterio.crs.CRS: CRS object
-        """
-
-        raw_crs = self._get_raw_crs()
-
-        if raw_crs.is_projected:
-            utm = raw_crs
-        else:
-            # Open metadata
-            root, _ = self.read_mtd()
-
-            # Open the Bounding_Polygon
-            vertices = list(root.iterfind(".//Dataset_Frame/Vertex"))
-
-            # Get the mean lon lat
-            lon = float(np.mean([float(v.findtext("FRAME_LON")) for v in vertices]))
-            lat = float(np.mean([float(v.findtext("FRAME_LAT")) for v in vertices]))
-
-            # Compute UTM crs from center long/lat
-            utm = vectors.corresponding_utm_projection(lon, lat)
-            utm = riocrs.CRS.from_string(utm)
-
-        return utm
-
     def _get_raw_crs(self) -> riocrs.CRS:
         """
         Get raw CRS of the tile
@@ -486,128 +453,8 @@ class Spot45Product(VhrProduct):
 
         return riocrs.CRS.from_string(crs_name)
 
-    @cache
-    @simplify
-    def footprint(self) -> gpd.GeoDataFrame:
-        """
-        Get real footprint in UTM of the products (without nodata, in french == emprise utile)
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> path = r"IMG_PHR1B_PMS_001"
-            >>> prod = Reader().open(path)
-            >>> prod.footprint()
-                                                         gml_id  ...                                           geometry
-            0  source_image_footprint-DS_PHR1A_20200511023124...  ...  POLYGON ((707025.261 9688613.833, 707043.276 9...
-            [1 rows x 3 columns]
-
-        Returns:
-            gpd.GeoDataFrame: Footprint as a GeoDataFrame
-        """
-        # If ortho -> nodata is not set !
-        if self.is_ortho:
-            # Get footprint of the first band of the stack
-            footprint_dezoom = 10
-            arr = rasters.read(
-                self.get_default_band_path(),
-                resolution=self.resolution * footprint_dezoom,
-                indexes=[1],
-            )
-
-            # Vectorize the nodata band (rasters_rio is faster)
-            footprint = rasters.vectorize(
-                arr, values=0, keep_values=False, dissolve=True
-            )
-            footprint = vectors.get_wider_exterior(footprint)
-        else:
-            # If not ortho -> default band has been orthorectified and nodata will be set
-            footprint = rasters.get_footprint(self.get_default_band_path())
-
-        return footprint.to_crs(self.crs())
-
-    @cache
-    def extent(self, **kwargs) -> gpd.GeoDataFrame:
-        """
-        Get UTM extent of the tile.
-
-        Returns:
-            gpd.GeoDataFrame: Extent in UTM
-        """
-        # TODO: SAME AS DIMAP
-        # Get MTD XML file
-        root, _ = self.read_mtd()
-
-        # Compute extent corners
-        corners = [
-            [float(vertex.findtext("FRAME_LON")), float(vertex.findtext("FRAME_LAT"))]
-            for vertex in root.iterfind(".//Dataset_Frame/Vertex")
-        ]
-
-        # When PRJ, Dataset_Frame is the footprint
-        ds_frame = gpd.GeoDataFrame(
-            geometry=[Polygon(corners)],
-            crs=vectors.WGS84,
-        ).to_crs(self.crs())
-
-        extent = gpd.GeoDataFrame(
-            geometry=[box(*ds_frame.total_bounds)],
-            crs=self.crs(),
-        )
-
-        return extent
-
-    def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
-        """
-        Get the product's acquisition datetime, with format :code:`YYYYMMDDTHHMMSS` <-> :code:`%Y%m%dT%H%M%S`
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> path = r"IMG_PHR1B_PMS_001"
-            >>> prod = Reader().open(path)
-            >>> prod.get_datetime(as_datetime=True)
-            datetime.datetime(2020, 5, 11, 2, 31, 58)
-            >>> prod.get_datetime(as_datetime=False)
-            '20200511T023158'
-
-        Args:
-            as_datetime (bool): Return the date as a datetime.datetime. If false, returns a string.
-
-        Returns:
-             Union[str, datetime.datetime]: Its acquisition datetime
-        """
-        # TODO: SAME AS DIMAP
-        if self.datetime is None:
-            # Get MTD XML file
-            root, _ = self.read_mtd()
-            date_str = root.findtext(".//IMAGING_DATE")
-            time_str = root.findtext(".//IMAGING_TIME")
-            if not date_str or not time_str:
-                raise InvalidProductError(
-                    "Cannot find the product imaging date and time in the metadata file."
-                )
-
-            # Convert to datetime
-            date_dt = date.fromisoformat(date_str)
-            time_dt = time.strptime(time_str, "%H:%M:%S")
-
-            date_str = (
-                f"{date_dt.strftime('%Y%m%d')}T{time.strftime('%H%M%S', time_dt)}"
-            )
-
-            if as_datetime:
-                date_str = datetime.strptime(date_str, DATETIME_FMT)
-
-        else:
-            date_str = self.datetime
-            if not as_datetime:
-                date_str = date_str.strftime(DATETIME_FMT)
-
-        return date_str
-
     def _get_constellation(self) -> Constellation:
-        """ Getter of the constellation """
+        """Getter of the constellation"""
         if self.split_name[0] == "SP04":
             const = Constellation.SPOT4
         elif self.split_name[0] == "SP05":
@@ -653,34 +500,6 @@ class Spot45Product(VhrProduct):
 
         return name
 
-    @cache
-    def get_mean_sun_angles(self) -> (float, float):
-        """
-        Get Mean Sun angles (Azimuth and Zenith angles)
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> path = r"IMG_PHR1A_PMS_001"
-            >>> prod = Reader().open(path)
-            >>> prod.get_mean_sun_angles()
-            (45.6624568841367, 30.219881316357643)
-
-        Returns:
-            (float, float): Mean Azimuth and Zenith angle
-        """
-        # Get MTD XML file
-        root, _ = self.read_mtd()
-
-        # Open zenith and azimuth angle
-        elev_angle = float(root.findtext(".//SUN_ELEVATION"))
-        azimuth_angle = float(root.findtext(".//SUN_AZIMUTH"))
-
-        # From elevation to zenith
-        zenith_angle = 90.0 - elev_angle
-
-        return azimuth_angle, zenith_angle
-
     @cache
     def get_mean_viewing_angles(self) -> (float, float, float):
         """
@@ -744,15 +563,24 @@ class Spot45Product(VhrProduct):
         """
         if self._raw_units == RawUnits.REFL:
             # Compute the correct radiometry of the band
-            original_dtype = band_arr.encoding.get("dtype", band_arr.dtype)
+            original_dtype = band_arr.encoding["dtype"]
             if original_dtype == "uint16":
                 band_arr /= 10000.0
         elif self._raw_units == RawUnits.DN:
             # Convert DN into radiance
             band_arr = self._dn_to_toa_rad(band_arr, band)
 
+            # Get the solar irradiance value of raw radiometric Band (in watt/m2/micron)
+            root, _ = self.read_mtd()
+            instrument_idx = int(root.findtext(".//INSTRUMENT_INDEX")) - 1
+
+            if self.constellation == Constellation.SPOT4:
+                e0 = _SPOT4_E0[band][instrument_idx]
+            else:
+                e0 = _SPOT5_E0[band][instrument_idx]
+
             # Convert radiance into reflectance
-            band_arr = self._toa_rad_to_toa_refl(band_arr, band)
+            band_arr = self._toa_rad_to_toa_refl(band_arr, band, e0=e0)
 
         else:
             LOGGER.warning(
@@ -781,32 +609,6 @@ class Spot45Product(VhrProduct):
 
         return self._read_mtd_xml(mtd_from_path, mtd_archived)
 
-    def _has_cloud_band(self, band: BandNames) -> bool:
-        """
-        Does this product has the specified cloud band ?
-        """
-        return False
-
-    def _open_clouds(
-        self,
-        bands: list,
-        resolution: float = None,
-        size: Union[list, tuple] = None,
-        **kwargs,
-    ) -> dict:
-        """
-        Load cloud files as xarrays.
-
-        Args:
-            bands (list): List of the wanted bands
-            resolution (int): Band resolution in meters
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
-            kwargs: Additional arguments
-        Returns:
-            dict: Dictionary {band_name, band_xarray}
-        """
-        return {}
-
     def _get_tile_path(self) -> Union[CloudPath, Path]:
         """
         Get the DIMAP filepath
@@ -852,45 +654,6 @@ class Spot45Product(VhrProduct):
             )
         return dn_arr / rad_gain + rad_bias
 
-    def _toa_rad_to_toa_refl(
-        self, rad_arr: xr.DataArray, band: BandNames
-    ) -> xr.DataArray:
-        """
-        Compute TOA reflectance from TOA radiance
-
-        See
-        `here <https://spot.cnes.fr/sites/default/files/migration/smsc/spot/calibration_synthesis_SPOT1245_ed1.pdf>`_
-        for more information.
-
-        Args:
-            rad_arr (xr.DataArray): TOA Radiance array
-            band (BandNames): Band
-
-        Returns:
-            xr.DataArray: TOA Reflectance array
-        """
-        # Get MTD XML file
-        root, _ = self.read_mtd()
-
-        # Get the solar irradiance value of raw radiometric Band (in watt/m2/micron)
-        instrument_idx = int(root.findtext(".//INSTRUMENT_INDEX")) - 1
-
-        if self.constellation == Constellation.SPOT4:
-            e0 = _SPOT4_E0[band][instrument_idx]
-        else:
-            e0 = _SPOT5_E0[band][instrument_idx]
-
-        # Compute the coefficient converting TOA radiance in TOA reflectance
-        dt = self._sun_earth_distance_variation()
-        _, sun_zen = self.get_mean_sun_angles()
-        rad_sun_zen = np.deg2rad(sun_zen)
-
-        # WARNING: d = 1 / sqrt(d(t))
-        toa_refl_coeff = np.pi / (e0 * dt * np.cos(rad_sun_zen))
-
-        # LOGGER.debug(f"rad to refl coeff = {toa_refl_coeff}")
-        return rad_arr.copy(data=toa_refl_coeff * rad_arr)
-
     def get_quicklook_path(self) -> str:
         """
         Get quicklook path if existing.
